from django.core.management.base import NoArgsCommand
from pillowtop.run_pillowtop import import_pillows

class Command(NoArgsCommand):
    help = "Reset checkpoints for pillowtop"
    def handle_noargs(self, **options):
        if options.get('interactive'):
            confirm = raw_input("""
            You have requested to reset the checkpoints for pillowtop. This is an irreversible
            operation, and may take a long time, and cause extraneous updates to the requisite
            consumers of the _changes feeds  Are you sure you want to do this?

Type 'yes' to continue, or 'no' to cancel: """)
        else:
            confirm = 'yes'

        if confirm != 'yes':
            print "Reset cancelled."
            return

        for pillow in import_pillows():
            print "Resetting checkpoint for %s" % pillow.get_checkpoint_doc_name()
            pillow.reset_checkpoint()







from gevent import monkey; monkey.patch_all()
from gevent.pool import Pool
from restkit.session import set_session; set_session("gevent")
from pillowtop.utils import import_pillows


#standalone pillowtop runner
def start_pillows():
    #gevent patching: logging doesn't seem to work unless thread is not patched

    pillows = import_pillows()
    pool = Pool(len(pillows))
    while True:
        for p in pillows:
            pool.spawn(p.run)
        pool.join()
        print "Pillows all joined and completed - restarting again"
        #this shouldn't happen

if __name__ == "__main__":
    start_pillows()




from optparse import make_option
from django.core.management.base import NoArgsCommand

from restkit.conn import Connection
from socketpool.pool import ConnectionPool
from pillowtop.run_pillowtop import start_pillows

class Command(NoArgsCommand):
    help = "Run the pillowtop management command to scan all _changes feeds"
    option_list = NoArgsCommand.option_list + (
    )
    def handle_noargs(self, **options):
        start_pillows()







class PillowtopConfigurationException(Exception):
    pass


def import_settings():
    try:
        from django.conf import settings
    except Exception, ex:
        #if we are not in a django context, then import local pillowsettings
        print "django import"
        print ex
        import pillowsettings as settings
    return settings


def import_pillows(instantiate=True):
    settings = import_settings()

    pillowtops = []
    if hasattr(settings, 'PILLOWTOPS'):
        for full_str in settings.PILLOWTOPS:
            comps = full_str.split('.')
            pillowtop_class_str = comps[-1]
            mod_str = '.'.join(comps[0:-1])
            mod = __import__(mod_str, {},{},[pillowtop_class_str])
            if hasattr(mod, pillowtop_class_str):
                pillowtop_class  = getattr(mod, pillowtop_class_str)
                pillowtops.append(pillowtop_class() if instantiate else pillowtop_class)
            else:
                raise PillowtopConfigurationException("Error, the pillow class %s could not be imported" % full_str)
    return pillowtops


import logging

# import local settings if we find them
try:
    #try to see if there's an environmental variable set for local_settings
    from local_pillow import *
except ImportError, e:
    logging.error("Local settings not found, loading defaults: %s" % (e))

